@@ -1,5 +1,5 @@
 package Storage::Abstract::Driver;
-$Storage::Abstract::Driver::VERSION = '0.001';
+$Storage::Abstract::Driver::VERSION = '0.002';
 use v5.14;
 use warnings;
 
@@ -113,9 +113,24 @@ sub copy_handle
 
 sub common_properties
 {
-	my ($self) = @_;
+	my ($self, $handle) = @_;
+	my $size = do {
+		if (fileno $handle == -1) {
+			my $success = (my $pos = tell $handle) >= 0;
+			$success &&= seek $handle, 0, 2;
+			$success &&= (my $res = tell $handle) >= 0;
+			$success &&= seek $handle, $pos, 0;
+
+			$success or Storage::Abstract::X::HandleError->raise($!);
+			$res;
+		}
+		else {
+			-s $handle;
+		}
+	};
 
 	return {
+		size => $size,
 		mtime => time,
 	};
 }
@@ -150,6 +165,13 @@ sub dispose_impl
 	...;
 }
 
+sub list_impl
+{
+	my ($self) = @_;
+
+	...;
+}
+
 # PUBLIC INTERFACE
 
 sub store
@@ -204,6 +226,13 @@ sub dispose
 	return;
 }
 
+sub list
+{
+	my ($self) = @_;
+
+	return $self->list_impl;
+}
+
 1;
 
 __END__
@@ -277,11 +306,12 @@ C<print>. Use this to move data between filehandles in driver classes.
 
 =head3 common_properties
 
-	my $properties = $obj->common_properties;
+	my $properties = $obj->common_properties($handle);
 
 This returns a hash reference containing a list of properties with default
-values. Currently, the only property avialible in all the drivers is C<mtime> -
-modification time.
+values. Note that this does not get all these properties from C<$handle>, but
+instead produces a new list of properties for drivers which must create it
+themselves (like L<Storage::Abstract::Driver::Memory>).
 
 =head2 Implementation methods
 
@@ -289,21 +319,21 @@ These methods must be reimplemented in driver classes:
 
 =over
 
-=item * store_impl
+=item * C<store_impl>
 
 	store_impl($path, $fh)
 
 The implementation of storing a new file in the storage. It will be passed a
 normalized path and an opened file handle. Its return value will be ignored.
 
-=item * is_stored_impl
+=item * C<is_stored_impl>
 
 	is_stored_impl($path)
 
 The implementation of checking whether a file is stored. It will be passed a
 normalized path. Must return a boolean.
 
-=item * retrieve_impl
+=item * C<retrieve_impl>
 
 	retrieve_impl($path, \%properties)
 
@@ -317,7 +347,7 @@ L</common_properties>.
 It should not check C<is_stored> - it will never be called without checking
 C<is_stored> first. Must return an opened file handle to the file.
 
-=item * dispose_impl
+=item * C<dispose_impl>
 
 	dispose_impl($path)
 
@@ -326,5 +356,12 @@ The implementation of disposing a file. First argument is a normalized path.
 It should not check C<is_stored> - it will never be called without checking
 C<is_stored> first. Its return value will be ignored.
 
+=item * C<list_impl>
+
+	list_impl($path)
+
+The implementation of getting a list of files. Should return an array reference
+with file names (in Unix format).
+
 =back
 
