@@ -1,5 +1,5 @@
 package Storage::Abstract::Driver::Null;
-$Storage::Abstract::Driver::Null::VERSION = '0.001';
+$Storage::Abstract::Driver::Null::VERSION = '0.002';
 use v5.14;
 use warnings;
 
@@ -31,6 +31,11 @@ sub dispose_impl
 	# will never be called
 }
 
+sub list_impl
+{
+	return [];
+}
+
 1;
 
 __END__
