@@ -9,6 +9,7 @@ use File::Spec;
 use Exporter qw(import);
 our @EXPORT = qw(
 	get_testfile
+	get_testfile_size
 	get_testfile_handle
 	slurp_handle
 );
@@ -23,6 +24,14 @@ sub get_testfile
 	return File::Spec->catdir(@testdir, $name);
 }
 
+sub get_testfile_size
+{
+	my ($name) = @_;
+
+	my $file = get_testfile($name);
+	return -s $file;
+}
+
 sub get_testfile_handle
 {
 	my ($name) = @_;
